cordex.regions package
======================

Submodules
----------

cordex.regions.germany module
-----------------------------

.. automodule:: cordex.regions.germany
    :members:
    :undoc-members:
    :show-inheritance:

cordex.regions.mask module
--------------------------

.. automodule:: cordex.regions.mask
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cordex.regions
    :members:
    :undoc-members:
    :show-inheritance:
